# Changelog

All notable changes to this project will be documented in this file.
## [0.1.1] - 2024-09-25

### Added

- Relative path management in uri
- Support for getting predefined config in the template location

### Fixed

- Tag message when -f is used (noxfile)
- Relative file path management for uri
- Coverage report not workingl
- Uri management
- Streamline of arg namespace
- Prep error message in noxfile template
- Wrong option attribute for git-clif output

## [0.1.0] - 2024-09-17

### Added

- Initial commit

<!-- generated by git-cliff -->
